<?php

function one_paze_page_lists() {
    $pages = get_pages();
    $page_list = array();
    $page_list[0] = __('Select Page', 'one-paze');
    foreach ($pages as $page) :
        $page_list[$page->ID] = $page->post_title;
    endforeach;
    return $page_list;
}

function one_paze_category_lists() {
    $categories = get_categories(
            array(
                'hide_empty' => 0,
                'exclude' => 1
            )
    );

    $category_list = array();
    $category_list[0] = __('Select Category', 'one-paze');
    foreach ($categories as $category) :
        $category_list[$category->term_id] = $category->name;
    endforeach;
    return $category_list;
}

if(!function_exists('one_paze_get_parallax_sections')) {
    function one_paze_get_parallax_sections() {
        $sections = array('about', 'portfolio', 'services', 'blog', 'cta', 'testimonial', 'team', 'contact');
        $enabled_section = array();
        foreach ($sections as $section) :
            if (esc_attr(get_theme_mod($section . '_section_enable')) == 1) :
                $enabled_section[] = array(
                    'id' => 'plx_' . $section . '_section',
                    'menu_text' => esc_attr(get_theme_mod($section . '_section_menu_title','')),
                    'section' => $section,
                );
            endif;
        endforeach;
        return $enabled_section;
    }    
}

function one_paze_slider_bx() {
    $enable_slider_overlay = esc_attr(get_theme_mod('enable_slider_overlay', ''));
    $slider_readmore_text = esc_attr(get_theme_mod('slider_readmore_text', 'Call To Action'));
    $slider_category = esc_attr(get_theme_mod('slider_category', 0));
    $sl_args = array('post_type' => 'post', 'posts_per_page' => 5, 'cat' => $slider_category );
    $sl_query = new WP_Query($sl_args);
    
    if($slider_category != '' || $slider_category != 0) :
        if($sl_query->have_posts()) :
        ?>
            <section id="plx-slider-section">
                <ul class='main-slider'>
                    <?php 
                        while($sl_query->have_posts()) : $sl_query->the_post();
                        $img = wp_get_attachment_image_src(get_post_thumbnail_id(), 'one-paze-slider-image-size');
                        $img_src = $img[0];
                        $image_attr =  "style = 'background-image: url(".esc_url($img_src).")';";
                    ?>
                    <li class="slide" <?php echo $image_attr; ?> >
                        <?php if ($enable_slider_overlay == 1) : ?>
                            <div class="slider-overlay1">
                            </div>
                        <?php endif; ?>
                        <div class="slide-caption">
                            <span class="caption-title"><?php the_title(); ?></span>
                            <span class="caption-descr"><?php the_content(); ?></span>
                            <?php if($slider_readmore_text != '') : ?>
                            <a class="cta_read" href="<?php the_permalink(); ?>" >
                                <?php echo esc_html($slider_readmore_text); ?>
                            </a>
                            <?php endif; ?>
                        </div>
                    </li>
                    <?php endwhile; ?>
                </ul>
                <div class="slider-down-btn">
                    <span class="next-page">
                        <a href="#plx_about_section"><i class="fa fa-angle-double-down"></i></a>
                    </span>
                </div>
            </section>
        <?php
        endif;
    endif;
}

function one_paze_slider_bxr() {
    $enable_slider_overlay = esc_attr(get_theme_mod('enable_slider_overlay'));
    $slides = array();
    for ($i = 1; $i < 5; $i++) {
        $sl_imageo = esc_attr(get_theme_mod('slide' . $i . '_image'));
        $img_id = attachment_url_to_postid(esc_url($sl_imageo));
        $img_arr = wp_get_attachment_image_src($img_id, 'one-paze-slider-image-size');
        $sl_image = $img_arr[0];
        
        $sl_cap_title = get_theme_mod('slide' . $i . '_caption_title');
        $sl_cap_descr = get_theme_mod('slide' . $i . '_caption_descr');
        $sl_btn_text = get_theme_mod('slide' . $i . '_button_text');
        $sl_btn_link = get_theme_mod('slide' . $i . '_button_link');
        if ($sl_image != '') {
            $slides[] = array(
                'image' => $sl_image,
                'caption_title' => $sl_cap_title,
                'caption_descr' => $sl_cap_descr,
                'btn_text' => $sl_btn_text,
                'btn_link' => $sl_btn_link
            );
        }
    }

    if (!empty($slides)) :
        ?>
        <section id="plx-slider-section">
            <ul class='main-slider'>
                <?php
                foreach ($slides as $slide) :
                    ?>
                    <li class="slide">
                        <img src="<?php echo esc_url($slide['image']); ?>" />
                        <?php if ($enable_slider_overlay == 1) : ?>
                            <div class="slider-overlay1">
                            </div>
                        <?php endif; ?>
                        <div class="slide-caption">
                            <span class="caption-title"><?php echo esc_html($slide['caption_title']); ?></span>
                            <span class="caption-descr"><?php echo wp_kses_post($slide['caption_descr']); ?></span>
                            <a class="cta_read" href="<?php echo esc_url($slide['btn_link']); ?>" >
                                <?php echo esc_html( $slide['btn_text'] ); ?>
                            </a>
                        </div>
                    </li>                          
                    <?php
                endforeach;
                ?>
            </ul>
            <div class="slider-down-btn">
                <span class="next-page">
                    <a href="#plx_about_section"><i class="fa fa-angle-double-down"></i></a>
                </span>
            </div>
        </section>
        <?php
    endif;
}

add_action('one_paze_slider', 'one_paze_slider_bx');

function one_paze_breadcrumb_cb() {
    global $post;
    $showOnHome = 0; // 1 - show breadcrumbs on the homepage, 0 - don't show
    $portfolio_section_category = get_theme_mod('portfolio_section_category', 0);

    $delimiter = '&#124;'; // delimiter between crumbs

    $home = esc_html__('Home', 'one-paze'); // text for the 'Home' link

    $showCurrent = 1; // 1 - show current post/page title in breadcrumbs, 0 - don't show
    $before = '<span class="current">'; // tag before the current crumb
    $after = '</span>'; // tag after the current crumb

    $homeLink = home_url();

    if (is_home() || is_front_page()) {
        if ($showOnHome == 1)
            echo '<div id="onepager-breadcrumbs"><div class="ap-container"><a href="' . esc_url($homeLink) . '">' . esc_html($home) . '</a></div></div>';
    } else {
        echo '<div id="onepager-breadcrumbs"><div class="ap-container"><a href="' . esc_url($homeLink) . '">' . esc_html($home) . '</a> ' . wp_kses_post($delimiter) . ' ';

        if (is_category()) {
            $thisCat = get_category(get_query_var('cat'), false);
            if ($thisCat->parent != 0)
                echo wp_kses_post(get_category_parents($thisCat->parent, TRUE, ' ' . $delimiter . ' '));
            if ($portfolio_section_category != 0 && $thisCat->term_id == $portfolio_section_category){
                echo wp_kses_post($before) . wp_kses_post(single_cat_title('', false)) . wp_kses_post($after);
            } else {
                echo wp_kses_post($before) . esc_html("Archive by category", "one-paze") .'"' . wp_kses_post(single_cat_title('', false)) . '"' . wp_kses_post($after);
            }
        } elseif (is_search()) {
            echo wp_kses_post($before) . esc_html("Search results for", "one-paze") .'"' . get_search_query() . '"' . wp_kses_post($after);
        } elseif (is_day()) {
            echo '<a href="' . esc_url(get_year_link(get_the_time('Y'))) . '">' . esc_html(get_the_time('Y')) . '</a> ' . wp_kses_post($delimiter) . ' ';
            echo '<a href="' . esc_url(get_month_link(get_the_time('Y'), get_the_time('m'))) . '">' . esc_html(get_the_time('F')) . '</a> ' . wp_kses_post($delimiter) . ' ';
            echo wp_kses_post($before) . esc_html(get_the_time('d')) . wp_kses_post($after);
        } elseif (is_month()) {
            echo '<a href="' . esc_url(get_year_link(get_the_time('Y'))) . '">' . esc_html(get_the_time('Y')) . '</a> ' . wp_kses_post($delimiter) . ' ';
            echo wp_kses_post($before) . esc_html(get_the_time('F')) . wp_kses_post($after);
        } elseif (is_year()) {
            echo wp_kses_post($before) . esc_html(get_the_time('Y')) . wp_kses_post($after);
        } elseif (is_single() && !is_attachment()) {
            if (get_post_type() != 'post') {
                $post_type = get_post_type_object(get_post_type());
                $slug = $post_type->rewrite;
                echo '<a href="' . esc_url($homeLink) . '/' . esc_attr($slug['slug']) . '/">' . esc_html($post_type->labels->singular_name) . '</a>';
                if ($showCurrent == 1)
                    echo ' ' . wp_kses_post($delimiter) . ' ' . wp_kses_post($before) . esc_html(get_the_title()) . wp_kses_post($after);
            } else {
                $cat = get_the_category();
                $cat = $cat[0];
                $cats = get_category_parents($cat, TRUE, ' ' . wp_kses_post($delimiter) . ' ');
                $proj_cat = esc_html(get_theme_mod('portfolio_section_category'));
                if ($showCurrent == 0)
                    $cats = preg_replace("#^(.+)\s$delimiter\s$#", "$1", $cats);
                echo wp_kses_post($cats);
                if ($showCurrent == 1)
                    echo wp_kses_post($before) . esc_html(get_the_title()) . wp_kses_post($after);
            }
        } elseif (!is_single() && !is_page() && get_post_type() != 'post' && !is_404()) {
            $post_type = get_post_type_object(get_post_type());
            echo wp_kses_post($before) . esc_html($post_type->labels->singular_name) . wp_kses_post($after);
        } elseif (is_attachment()) {
            $parent = get_post($post->post_parent);
            $cat = get_the_category($parent->ID);
            $cat = $cat[0];
            echo wp_kses_post(get_category_parents($cat, TRUE, ' ' . $delimiter . ' '));
            echo '<a href="' . esc_url(get_permalink($parent)) . '">' . esc_html($parent->post_title) . '</a>';
            if ($showCurrent == 1)
                echo ' ' . wp_kses_post($delimiter) . ' ' . wp_kses_post($before) . esc_html(get_the_title()) . wp_kses_post($after);
        } elseif (is_page() && !$post->post_parent) {
            if ($showCurrent == 1)
                echo wp_kses_post($before) . esc_html(get_the_title()) . wp_kses_post($after);
        } elseif (is_page() && $post->post_parent) {
            $parent_id = $post->post_parent;
            $breadcrumbs = array();
            while ($parent_id) {
                $page = get_page($parent_id);
                $breadcrumbs[] = '<a href="' . esc_url(get_permalink($page->ID)) . '">' . esc_html(get_the_title($page->ID)) . '</a>';
                $parent_id = $page->post_parent;
            }
            $breadcrumbs = array_reverse($breadcrumbs);
            for ($i = 0; $i < count($breadcrumbs); $i++) {
                echo wp_kses_post($breadcrumbs[$i]);
                if ($i != count($breadcrumbs) - 1)
                    echo ' ' . wp_kses_post(wp_kses_post($delimiter)) . ' ';
            }
            if ($showCurrent == 1)
                echo ' ' . wp_kses_post($delimiter) . ' ' . wp_kses_post($before) . esc_html(get_the_title()) . wp_kses_post($after);
        } elseif (is_tag()) {
            echo wp_kses_post($before) . esc_html("Posts tagged", "one-paze") . ' ' . esc_html(single_tag_title('', false)) . '"' . wp_kses_post($after);
        } elseif (is_author()) {
            global $author;
            $userdata = get_userdata($author);
            echo wp_kses_post($before) . esc_html("Articles posted by", "one-paze") .' ' . esc_html($userdata->display_name) . wp_kses_post($after);
        } elseif (is_404()) {
            echo wp_kses_post($before) . esc_html("Error 404", "one-paze") . ' ' . wp_kses_post($after);
        }

        if (get_query_var('paged')) {
            if (is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author())
                echo ' (';
            esc_html_e('Page', 'one-paze') . ' ' . get_query_var('paged');
            if (is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author())
                echo ')';
        }

        echo '</div></div>';
    }
}

add_action('one_paze_breadcrumb', 'one_paze_breadcrumb_cb');

/** Is home page with set to display latest posts and parallax is enabled * */

/** Assign Class for Blog Page Layout **/
function one_paze_assign_alt_classes( $classes ) {
    	global $post;
        static $flag = true;
        
        if($flag){
            $classes[] = 'alt-left';
            $flag = false;
        }else{
            $classes[] = 'alt-right';
            $flag = true;
        }
        
    	return $classes;
    }
if(esc_attr(get_theme_mod('blog_page_layouts')) == 'blog_image_alt_medium'){
    add_filter( 'post_class', 'one_paze_assign_alt_classes' );
} 

if( class_exists( 'WP_Customize_Control' ) ) :
    class WP_Customize_Ohelp_Control extends WP_Customize_Control{            
        public function render_content() {
            $input_attrs = $this->input_attrs;
            $info = isset($input_attrs['info']) ? $input_attrs['info'] : '';
            ?>
            <div class="help-info">
                <h4><?php esc_html_e('Instruction', 'one-paze'); ?></h4>
                <div style="font-weight: bold;">
                    <?php echo wp_kses_post($info); ?>
                </div>
            </div>
            <?php
        }
    }
endif;

// Our Product detail's
if(class_exists( 'WP_Customize_control')){
    class Theme_Info_Product_Custom_Control extends WP_Customize_Control
    {
        public function render_content()
        {
            ?>
            <label>
                <!-- <h3 class="customize-title"><?php //echo esc_html( $this->label ); ?></h3>
                <br /> -->
                <span class="customize-text_editor_desc button">
                    <?php echo wp_kses_post( $this->description ); ?>
                </span>
            </label>
            <?php
        }
    }
}

// Extra Controls
if(class_exists( 'WP_Customize_control')){
    /**
     * Pro customizer section.
     *
     * @since  1.0.0
     * @access public
     */
    class One_Paze_Customize_Section_Pro extends WP_Customize_Section {

        /**
         * The type of customize section being rendered.
         *
         * @since  1.0.0
         * @access public
         * @var    string
         */
        public $type = 'onepaze-pro';

        /**
         * Custom button text to output.
         *
         * @since  1.0.0
         * @access public
         * @var    string
         */
        public $pro_text = '';

        /**
         * Custom pro button URL.
         *
         * @since  1.0.0
         * @access public
         * @var    string
         */
        public $pro_url = '';

        /**
         * Add custom parameters to pass to the JS via JSON.
         *
         * @since  1.0.0
         * @access public
         * @return void
         */
        public function json() {
            $json = parent::json();
            $json['pro_text'] = $this->pro_text;
            $json['pro_url']  = esc_url( $this->pro_url );
            return $json;
        }

        /**
         * Outputs the Underscore.js template.
         *
         * @since  1.0.0
         * @access public
         * @return void
         */
        protected function render_template() { ?>

            <li id="accordion-section-{{ data.id }}" class="accordion-section control-section control-section-{{ data.type }} cannot-expand">
                <h3 class="accordion-section-title">
                    {{ data.title }}
                    <# if ( data.pro_text && data.pro_url ) { #>
                        <a href="{{ data.pro_url }}" class="button button-secondary alignright" target="_blank">{{ data.pro_text }}</a>
                    <# } #>
                </h3>
            </li>
        <?php }
    }
}
?>